summaryrefslogtreecommitdiffstats
path: root/korganizer/calendarview.h
diff options
context:
space:
mode:
Diffstat (limited to 'korganizer/calendarview.h')
-rw-r--r--korganizer/calendarview.h16
1 files changed, 8 insertions, 8 deletions
diff --git a/korganizer/calendarview.h b/korganizer/calendarview.h
index 2c5aeec5..9a180bb0 100644
--- a/korganizer/calendarview.h
+++ b/korganizer/calendarview.h
@@ -59,13 +59,13 @@ using namespace KCal;
class CalendarViewExtension : public TQWidget
{
public:
- CalendarViewExtension( TQWidget *tqparent, const char *name = 0 )
- : TQWidget( tqparent, name ) {}
+ CalendarViewExtension( TQWidget *parent, const char *name = 0 )
+ : TQWidget( parent, name ) {}
class Factory
{
public:
- virtual CalendarViewExtension *create( TQWidget *tqparent ) = 0;
+ virtual CalendarViewExtension *create( TQWidget *parent ) = 0;
};
};
@@ -86,10 +86,10 @@ class KDE_EXPORT CalendarView : public KOrg::CalendarViewBase, public Calendar::
/**
Constructs a new calendar view widget.
- @param tqparent tqparent window
+ @param parent parent window
@param name TQt internal widget object name
*/
- CalendarView( TQWidget *tqparent = 0, const char *name = 0 );
+ CalendarView( TQWidget *parent = 0, const char *name = 0 );
virtual ~CalendarView();
class CalendarViewVisitor : public IncidenceBase::Visitor
@@ -346,9 +346,9 @@ class KDE_EXPORT CalendarView : public KOrg::CalendarViewBase, public Calendar::
/** create new todo, due on date */
void newTodo( ResourceCalendar *res, const TQString &subRes,
const TQDate &date );
/** create new todo with a tqparent todo */
void newSubTodo();
/** create new todo with a tqparent todo */
void newSubTodo( Todo * );
void newTodo( ResourceCalendar *res, const TQString &subRes,
@@ -658,7 +658,7 @@ class KDE_EXPORT CalendarView : public KOrg::CalendarViewBase, public Calendar::
// uncompleted subitems), notAllPurged is set to true.
bool purgeCompletedSubTodos( Todo* todo, bool &notAllPurged );
/** Returns all incidences having inc has their tqparent (or grand tqparent, etc.)
inc is included in the list too.
*/
void getIncidenceHierarchy( Incidence *inc, Incidence::List &incidences );
@@ -346,9 +346,9 @@ class KDE_EXPORT CalendarView : public KOrg::CalendarViewBase, public Calendar::
void newTodo( ResourceCalendar *res, const TQString &subRes,
const TQDate &date );
- /** create new todo with a tqparent todo */
+ /** create new todo with a parent todo */
void newSubTodo();
@@ -346,9 +346,9 @@ class KDE_EXPORT CalendarView : public KOrg::CalendarViewBase, public Calendar::
void newSubTodo();
- /** create new todo with a tqparent todo */
+ /** create new todo with a parent todo */
void newSubTodo( Todo * );
void newTodo( ResourceCalendar *res, const TQString &subRes,
@@ -658,7 +658,7 @@ class KDE_EXPORT CalendarView : public KOrg::CalendarViewBase, public Calendar::
// uncompleted subitems), notAllPurged is set to true.
bool purgeCompletedSubTodos( Todo* todo, bool &notAllPurged );
- /** Returns all incidences having inc has their tqparent (or grand tqparent, etc.)
+ /** Returns all incidences having inc has their parent (or grand parent, etc.)
inc is included in the list too.
*/